﻿using System;
using System.ComponentModel;
using System.Windows;
using Telerik.Windows;
using Telerik.Windows.Controls;

namespace GridViewInComboBox
{
    public class GridViewExtensions
    {
        public static readonly Telerik.Windows.RoutedEvent SelectionChangedEvent =
            EventManager.RegisterRoutedEvent("SelectionChanged", RoutingStrategy.Bubble, typeof(RadRoutedEventHandler), typeof(FrameworkElement));

        public static bool GetEnableSelectionChangedRoutedEvent(DependencyObject obj)
        {
			return (bool)obj.GetValue(EnableSelectionChangedRoutedEventProperty);
        }

        public static void SetEnableSelectionChangedRoutedEvent(DependencyObject obj, bool value)
        {
			obj.SetValue(EnableSelectionChangedRoutedEventProperty, value);
        }

		public static readonly DependencyProperty EnableSelectionChangedRoutedEventProperty =
			DependencyProperty.RegisterAttached("EnableSelectionChangedRoutedEvent", typeof(bool), typeof(GridViewExtensions), 
            new System.Windows.PropertyMetadata(new PropertyChangedCallback(OnEnableSelectionChangedEventChanged)));

        private static void OnEnableSelectionChangedEventChanged(DependencyObject d, DependencyPropertyChangedEventArgs args)
        {
            RadGridView gridView = d as RadGridView;
            if (gridView != null)
            {
                if ((bool)args.NewValue)
                {
                    gridView.PropertyChanged += GridViewPropertyChanged;
                }
                else
                {
                    gridView.PropertyChanged -= GridViewPropertyChanged;
                }
            }
        }

        static void GridViewPropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            if (e.PropertyName == "SelectedItem")
            {
                (sender as RadGridView).RaiseEvent(new RadRoutedEventArgs(SelectionChangedEvent, sender));
            }
        }
    }
}